@@ -59,6 +59,7 @@
 #include "wallpaper.h"
 #include "dynamic-launcher.h"
 #include "externalwindow.h"
+#include "notification.h"
 
 
 static GMainLoop *loop = NULL;
@@ -203,6 +204,12 @@ on_bus_acquired (GDBusConnection *connection,
       g_warning ("error: %s\n", error->message);
       g_clear_error (&error);
     }
+
+  if (!notification_init (connection, &error))
+    {
+      g_warning ("error: %s\n", error->message);
+      g_clear_error (&error);
+    }
 }
 
 static void
